@@ -10,21 +10,17 @@
 """
 __author__ = "yanyongyu"
 
-from typing import Optional, AsyncIterator
 from contextlib import asynccontextmanager
+from typing import AsyncIterator, Optional
 
-from nonebot import get_driver
+from nonebot import get_plugin_config
 from nonebot.log import logger
-from playwright.async_api import Page, Error, Browser, Playwright, async_playwright
+from playwright.async_api import Browser, Error, Page, Playwright, async_playwright
 
-from nonebot_plugin_htmlrender.config import Config
+from .config import Config
+import asyncio
 
-
-class ConfigError(Exception):
-    pass
-
-
-config = Config.parse_obj(get_driver().config.dict())
+config = get_plugin_config(Config)
 
 _browser: Optional[Browser] = None
 _playwright: Optional[Playwright] = None
@@ -42,18 +38,23 @@ async def init(**kwargs) -> Browser:
     return _browser
 
 
-async def launch_browser(proxy=config.htmlrender_proxy_host, **kwargs) -> Browser:
+async def launch_browser(**kwargs) -> Browser:
     assert _playwright is not None, "Playwright 没有安装"
-    if proxy:
-        kwargs["proxy"] = proxy
+
+    if config.htmlrender_browser_channel:
+        kwargs["channel"] = config.htmlrender_browser_channel
+
+    if config.htmlrender_proxy_host:
+        kwargs["proxy"] = {
+            "server": config.htmlrender_proxy_host,
+        }
     if config.htmlrender_browser == "firefox":
         logger.info("使用 firefox 启动")
         return await _playwright.firefox.launch(**kwargs)
 
-    else:
-        # 默认使用 chromium
-        logger.info("使用 chromium 启动")
-        return await _playwright.chromium.launch(**kwargs)
+    # 默认使用 chromium
+    logger.info("使用 chromium 启动")
+    return await _playwright.chromium.launch(**kwargs)
 
 
 async def get_browser(**kwargs) -> Browser:
@@ -61,9 +62,9 @@ async def get_browser(**kwargs) -> Browser:
 
 
 @asynccontextmanager
-async def get_new_page(device_scale_factor:float = 2,**kwargs) -> AsyncIterator[Page]:
+async def get_new_page(device_scale_factor: float = 2, **kwargs) -> AsyncIterator[Page]:
     browser = await get_browser()
-    page = await browser.new_page(device_scale_factor=device_scale_factor,**kwargs)
+    page = await browser.new_page(device_scale_factor=device_scale_factor, **kwargs)
     try:
         yield page
     finally:
@@ -74,10 +75,11 @@ async def shutdown_browser():
     global _browser
     global _playwright
     if _browser:
-        await _browser.close()
+        if _browser.is_connected():
+            await _browser.close()
         _browser = None
     if _playwright:
-        await _playwright.stop()  # type: ignore
+        # await _playwright.stop()
         _playwright = None
 
 
@@ -92,9 +94,9 @@ async def install_browser():
         os.environ["PLAYWRIGHT_DOWNLOAD_HOST"] = host
     else:
         logger.info("使用镜像源进行下载")
-        os.environ[
-            "PLAYWRIGHT_DOWNLOAD_HOST"
-        ] = "https://npmmirror.com/mirrors/playwright/"
+        os.environ["PLAYWRIGHT_DOWNLOAD_HOST"] = (
+            "https://npmmirror.com/mirrors/playwright/"
+        )
     success = False
 
     if config.htmlrender_browser == "firefox":
@@ -106,7 +108,7 @@ async def install_browser():
         sys.argv = ["", "install", "chromium"]
     try:
         logger.info("正在安装依赖")
-        os.system("playwright install-deps")
+        os.system("playwright install-deps")  # noqa: ASYNC102, S605, S607
         main()
     except SystemExit as e:
         if e.code == 0:
